Hello. I am a mail screener working for Business Management Systems in Fairfax, VA. There is a problem with the domain:

> %domain

While this domain is properly configured for email, it has acquired quite a reputation for spam on emails where the authentication result is %qual. On a scale of -100 to 100, it scores %score.

If you are just an innocent user trying to send mail, then your mail server could be compromised. You can give us a call at 703-591-0911 and my boss can reset your domain reputation.